universal_file_handler
library
Classes
-
FileConfig
-
Configuration used while resolving, caching, and loading files.
-
FileUtils
-
Helper methods for working with supported file sources and cache keys.
-
ImageViewer
-
Full-screen viewer for image files resolved by the package.
-
PdfViewer
-
Full-screen viewer for PDF files resolved by the package.
-
ShareService
-
Wraps platform sharing for resolved files.
-
UniversalFileHandler
-
Public entry point for resolving, opening, caching, and sharing files.
Enums
-
FileSourceType
-
Supported source categories for incoming file references.
-
FileType
-
Supported file categories used by the package.