ImageViewer class
Full-screen viewer for image files resolved by the package.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ImageViewer
Constructors
Properties
- appBarBackgroundColor → Color?
-
Optional app bar background color.
final
- appBarTextColor → Color?
-
Optional color for the app bar title text.
final
- file → File
-
Local image file to display.
final
- floatingActionButtonBackgroundColor → Color?
-
Optional background color for the floating share button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideAppBar → bool
-
Whether the app bar should be hidden.
final
-
Optional bool for sharing icon by default true.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
Optional custom app bar leading widget.
final
- leadingIconColor → Color?
-
Optional color applied to icons in the custom leading widget.
final
- loadingWidget → Widget?
-
Optional loading UI. Defaults to an adaptive Material/Cupertino spinner.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Optional color for the share icon.
final
- tag → String?
-
Optional data for hero transitions.
final
- title → String?
-
Optional title shown in the app bar.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited